##  Saving and Publishing Templates from the Template Editor
Action | What happens | Who sees it | When to use
---|---|---|---
Autosave | Changes are continuously written to a draft copy while you edit. | Only you can access the draft copy until you publish it.  | Happens automatically when you're editing a template.
Save |
  * Saves the current state of the draft.
  * The template remains unpublished by default.

| Only you can access the template.  | When you want to preview your diagram while making changes.
Save as |
  * Creates a separate copy of the current template.
  * The original template remains unchanged and unpublished

| You can access the new template.  | When you want to create another version of an existing template or a variant with a different view.
Save and publish | Saves your draft and publishes the template to your workspace in one step. | You and others can access and use the template, depending on their permissions. | When your changes are ready for others to use. This is faster than manually publishing later.


